@@ -16,11 +16,20 @@ from .diagram import DataFlowDiagram, DiagramEdge, DiagramNode
 from .element import Element
 from .model import Model, ModelException
 from .node import Construct
-from .risk import Risk
+from .risk import ComponentRisk, ModelRisk, Risk
 from .score import Score
 from .table_format import TableFormat
 from .tag import TagMixin
-from .threat import BaseThreat, ComponentThreat, ModelThreat, Stride, ThreatLibrary
+from .threat import (
+    CAPEC,
+    LINDDUM,
+    STRIDE,
+    BaseThreat,
+    Category,
+    ComponentThreat,
+    ModelThreat,
+    ThreatLibrary,
+)
 from .trust_boundary import TrustBoundary
 from .user_story import UserStory, UserStoryTemplate, UserStoryTemplateRepository
 
@@ -47,14 +56,19 @@ __all__ = (
     "Model",
     "ModelException",
     "Construct",
+    "ComponentRisk",
+    "ModelRisk",
     "Risk",
     "Score",
     "TableFormat",
     "TagMixin",
+    "CAPEC",
+    "LINDDUM",
+    "STRIDE",
     "BaseThreat",
+    "Category",
     "ComponentThreat",
     "ModelThreat",
-    "Stride",
     "ThreatLibrary",
     "TrustBoundary",
     "UserStory",
